#include "examples.h"

const int DIMENSIONS = 2;    // number of dimensions
const int ITERATIONS = 18;   // number of iterations
                             // keep ITERATIONS <= 18 for gnuplot to work properly
                             // keep ITERATIONS <= 20 for memory allocation

const double BOX_K = 10;    // size of initial box [-BOX_K, BOX_K]
const double MAX_TIME = 0.2; // maximum time value

const int doLog = 0;         // 0 means no log files; 1 means create log files
const int doPlot = 1;        // 0 means no log files; 1 means create log files

const int dim1 = 0; // first dimension for 3d plot, usually 0
const int dim2 = 1; // second dimension for 3d plot, usually 1
const double MIN_RES = 0.01; // small cubes are not visible in gnuplot

char *equationName = "x' = y, y' = {g - k x for x > 0, g for x > 0,}; x(0) = -1, y(0) = 0";

void computeDerivativeValue(int dim, mpfi_t v, mpfi_t x[DIMENSIONS]) {
	double g_ = 10.0;
	double k_ = 20.0;

	mpfi_t y0;
	mpfi_init(y0);
	mpfi_sub_d(y0, x[0], 1);

	switch (dim) {
	case 0:
		if (mpfi_cmp_d(y0, 1) < 0) {
			mpfi_mul_d(v, y0, k_);
			mpfi_d_sub(v, g_, v);
		} else if (mpfi_cmp_d(y0, 1) > 0) {
			mpfi_set_d(v, g_);
		} else {
			mpfr_t right;
			mpfr_init(right);
			mpfi_get_right(right, y0);
			double x_ = mpfr_get_d(right, GMP_RNDN);
			mpfi_interv_d(v, (g_ - k_ * x_), g_);
			mpfr_clear(right);
		}
		break;
	case 1:
		mpfi_set(v, x[1]);
		break;
	}

	mpfi_clear(y0);
}
